package cn.kdan.pdf.backend.core.controller;

import cn.kdan.pdf.backend.core.constant.MembersConstant;
import cn.kdan.pdf.backend.core.model.Members;
import cn.kdan.pdf.backend.core.model.member.MemberInfoResp;
import cn.kdan.pdf.backend.core.model.member.MemberRegisterReq;
import cn.kdan.pdf.backend.core.model.member.MemberRegisterResp;
import cn.kdan.pdf.backend.core.model.member.ModifyPasswordReq;
import cn.kdan.pdf.backend.core.params.BindAccountParam;
import cn.kdan.pdf.backend.core.params.UserResetPwdParams;
import cn.kdan.pdf.backend.core.pojo.app.BindAccountVo;
import cn.kdan.pdf.backend.core.service.MemberService;
import constant.CommonConstant;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import pojo.AppRequestParam;
import pojo.AppResultMap;
import pojo.ResultMap;

/**
 * @author tangxiangan
 */
@RestController
@RequestMapping("/members")
public class MembersController {

    @Autowired
    private MemberService memberService;

    /**
     * 用户注册
     *
     * @param req 用户注册入参
     * @return 用户注册出参
     */
    @PostMapping("/register")
    public ResultMap<MemberRegisterResp> register(@RequestBody MemberRegisterReq req) {

        MemberRegisterResp register = memberService.register(req);
        return new ResultMap<>(CommonConstant.SUCCESS, "注册成功", register);
    }

    /**
     * 获取当前用户信息
     *
     * @return Members
     */
    @GetMapping("/me")
    public Members me() {
        return memberService.getCurrentUser();
    }

    /**
     * 修改密码
     *
     * @param req 用户修改密码入参
     * @return 修改成功提示信息
     */
    @PostMapping("modifyPassword")
    public ResultMap<String> modifyPassword(@RequestBody ModifyPasswordReq req) {
        memberService.modifyPassword(req);
        return new ResultMap<>(CommonConstant.SUCCESS, "修改密码成功", "修改密码成功");
    }

    /**
     * 修改昵称
     *
     * @param name 用户输入昵称
     * @return 修改成功提示信息
     */
    @GetMapping("modifyNickname")
    public ResultMap<String> modifyNickname(@RequestParam String name) {
        memberService.modifyNickname(name);
        return new ResultMap<>(CommonConstant.SUCCESS, "修改昵称成功", "修改昵称成功");
    }

    /**
     * 获取用户信息
     *
     * @param id 用户id（可不传）
     * @return 用户详细信息
     */
    @GetMapping("getMemberInfo")
    public ResultMap<MemberInfoResp> getMemberInfo(String id) {
        MemberInfoResp memberInfo = memberService.getMemberDetail(id);
        return new ResultMap<>(CommonConstant.SUCCESS, "获取用户信息成功", memberInfo);
    }


    /**
     * 用于忘记密码时重置密码
     *
     * @param params params
     * @return Boolean
     */
    @PostMapping("resetPassword")
    public ResultMap<Boolean> resetPassword(@RequestBody UserResetPwdParams params) {
        if (memberService.resetPassword(params)) {
            return new ResultMap<>(CommonConstant.SUCCESS, MembersConstant.PASSWORD_UPDATE_SUCCESS, true);
        } else {
            return new ResultMap<>(CommonConstant.SUCCESS, MembersConstant.PASSWORD_UPDATE_ERROR, false);
        }
    }

    /**
     * 注销账号
     * @return 提示信息
     */
    @GetMapping("/cancelAccount")
    public AppResultMap<String> cancelAccount(){
        String memberid = memberService.cancelAccount();
        return new AppResultMap<>(CommonConstant.SUCCESS,CommonConstant.CODE_SUCCESS,"注销账号成功");
    }

    /**
     * 绑定账号
     * @param param 入参
     * @return 绑定信息
     */
    @PostMapping("/bindAccount")
    public AppResultMap<BindAccountVo> bindAccount(@RequestBody AppRequestParam<BindAccountParam> param){
        BindAccountVo bindAccountVo = memberService.bindAccount(param.getData());
        return new AppResultMap<>(CommonConstant.SUCCESS,CommonConstant.CODE_SUCCESS,bindAccountVo);
    }

    /**
     * 解绑账号
     * @param param 入参
     * @return 解绑信息
     */
    @PostMapping("/unbindAccount")
    public AppResultMap<BindAccountVo> unbindAccount(@RequestBody AppRequestParam<BindAccountParam> param){
        return null;
    }

}
